@@ -10,16 +10,16 @@ no warnings;
 use Carp qw(croak carp);
 use Scalar::Util qw(blessed);
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD
+use vars qw( @ISA $AUTOLOAD
              $debug %names %elements $maximum_Z
              %names_to_Z $Default_language %Languages
             );
 
 use Exporter qw(import);
 
-@EXPORT_OK = qw(get_Z get_symbol get_name);
-@EXPORT    = qw();
-$VERSION   = '1.071';
+our @EXPORT_OK = qw(get_Z get_symbol get_name);
+our @EXPORT    = qw();
+our $VERSION   = '1.074';
 
 use subs qw(
 	_get_name_by_Z
@@ -64,7 +64,7 @@ $debug = 0;
 %Languages = (
 	'Pig Latin' => 0,
 	'English'   => 1,
-	'Japanese' => 2,
+	'Japanese'  => 2,
 	);
 
 $Default_language = $Languages{'English'};
@@ -210,13 +210,13 @@ $maximum_Z = pop @a;
 }
 
 my %elements = map { state $n = 0; $n++; $_ => $n, $n => $_ } qw(
-H                                                                                                He
-Li Be                                                                           B  C   N  O   F  Ne
-Na Mg                                                                          Al Si   P  S  Cl  Ar
-K  Ca                                           Sc Ti  V Cr Mn Fe Co Ni Cu Zn  Ga Ge  As Se  Br  Kr
-Rb Sr                                            Y Zr Nb Mo Tc Ru Rh Pd Ag Cd  In Sn  Sb Te   I  Xe
-Cs Ba La Ce Pr Nd Pm Sm Eu Gd Tb Dy Ho Er Tm Yb Lu Hf Ta W  Re Os Ir Pt Au Hg  Tl Pb  Bi Po  At  Rn
-Fr Ra Ac Th Pa U  Np Pu Am Cm Bk Cf Es Fm Md No Lr Rf Ha Sg Bh Hs Mt Ds Rg Cn Uut Fl Uup Lv Uus Uuo
+H                                                                                            He
+Li Be                                                                          B  C  N  O  F Ne
+Na Mg                                                                         Al Si  P  S Cl Ar
+K  Ca                                           Sc Ti  V Cr Mn Fe Co Ni Cu Zn Ga Ge As Se Br Kr
+Rb Sr                                            Y Zr Nb Mo Tc Ru Rh Pd Ag Cd In Sn Sb Te  I Xe
+Cs Ba La Ce Pr Nd Pm Sm Eu Gd Tb Dy Ho Er Tm Yb Lu Hf Ta W  Re Os Ir Pt Au Hg Tl Pb Bi Po At Rn
+Fr Ra Ac Th Pa U  Np Pu Am Cm Bk Cf Es Fm Md No Lr Rf Ha Sg Bh Hs Mt Ds Rg Cn Nh Fl Mc Lv Ts Og
 );
 
 sub new {
@@ -673,7 +673,7 @@ simply pretend that there is a molar_mass method:
 
 	$element->molar_mass($MM); #add molar mass datum in $MM to object
 
-Similiarly, you can retrieve previously set values by not specifying
+Similarly, you can retrieve previously set values by not specifying
 an argument to your pretend method:
 
 	$datum = $element->molar_mass();
@@ -713,9 +713,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2000-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2000-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the Artistic License 2.0.
 
 =cut
